pub struct Metadata {
pub product_uid: String,
pub version: String,
pub hardware: String,
pub pub_key: Option<PathBuf>,
pub device_identity: MetadataValue,
pub device_attributes: MetadataValue,
}Expand description
Metadata stores the firmware metadata information. It is organized in multiple fields.
The Metadata is created loading its information from the running
firmware. It uses the load method for that.
Fields
product_uid: StringProduct UID which identifies the firmware on the management system
version: StringVersion of firmware
hardware: StringHardware where the firmware is running
pub_key: Option<PathBuf>Path for the pub key being used
device_identity: MetadataValueDevice Identity
device_attributes: MetadataValueDevice Attributes